﻿/*
	SPDX-License-Identifier: MIT
	Copyright © 2023-2024 Amebis
*/

#pragma once

#include "string.hpp"

namespace stdex
{
	/// \cond internal
	struct sgml_unicode_pair {
		char sgml[12];       ///< Entity name (without leading & and trailing ;)
		char32_t unicode[3]; ///< UTF-32 string representation
	};

	inline const sgml_unicode_pair sgml_unicode[] = {
		{ "AElig", U"\u00c6" },
		{ "Aacgr", U"\u0386" },
		{ "Aacute", U"\u00c1" },
		{ "Aacute", U"\u0041\u0301" },
		{ "Abreve", U"\u0102" },
		{ "Abreve", U"\u0041\u0306" },
		{ "Abring", U"\u0041\u032f" },
		{ "Acaron", U"\u0041\u030c" },
		{ "Acirc", U"\u00c2" },
		{ "Acirc", U"\u0041\u0302" },
		{ "Acy", U"\u0410" },
		{ "Adot", U"\u0041\u0307" },
		{ "Agr", U"\u0391" },
		{ "Agrave", U"\u00c0" },
		{ "Agrave", U"\u0041\u0300" },
		{ "Alpha", U"\u0391" },
		{ "Amacr", U"\u0100" },
		{ "Amacr", U"\u0041\u0304" },
		{ "Aogon", U"\u0104" },
		{ "Aring", U"\u00c5" },
		{ "Atilde", U"\u00c3" },
		{ "Atilde", U"\u0041\u0303" },
		{ "Auml", U"\u00c4" },
		{ "Auml", U"\u0041\u0308" },
		{ "Bacute", U"\u0042\u0301" },
		{ "Barwed", U"\u2306" },
		{ "Bbreve", U"\u0042\u0306" },
		{ "Bbring", U"\u0042\u032f" },
		{ "Bcaron", U"\u0042\u030c" },
		{ "Bcirc", U"\u0042\u0302" },
		{ "Bcy", U"\u0411" },
		{ "Bdot", U"\u0042\u0307" },
		{ "Beta", U"\u0392" },
		{ "Bgr", U"\u0392" },
		{ "Bgrave", U"\u0042\u0300" },
		{ "Bmacr", U"\u0042\u0304" },
		{ "Btilde", U"\u0042\u0303" },
		{ "Buml", U"\u0042\u0308" },
		{ "CHcy", U"\u0427" },
		{ "Cacute", U"\u0106" },
		{ "Cacute", U"\u0043\u0301" },
		{ "Cap", U"\u22d2" },
		{ "Cbreve", U"\u0043\u0306" },
		{ "Cbring", U"\u0043\u032f" },
		{ "Ccaron", U"\u010c" },
		{ "Ccaron", U"\u0043\u030c" },
		{ "Ccedil", U"\u00c7" },
		{ "Ccirc", U"\u0108" },
		{ "Ccirc", U"\u0043\u0302" },
		{ "Cdot", U"\u010a" },
		{ "Cdot", U"\u0043\u0307" },
		{ "Cgrave", U"\u0043\u0300" },
		{ "Chi", U"\u03a7" },
		{ "Cmacr", U"\u0043\u0304" },
		{ "Ctilde", U"\u0043\u0303" },
		{ "Cuml", U"\u0043\u0308" },
		{ "Cup", U"\u22d3" },
		{ "DJcy", U"\u0402" },
		{ "DScy", U"\u0405" },
		{ "DZcy", U"\u040f" },
		{ "Dacute", U"\u0044\u0301" },
		{ "Dagger", U"\u2021" },
		{ "Dbreve", U"\u0044\u0306" },
		{ "Dbring", U"\u0044\u032f" },
		{ "Dcaron", U"\u010e" },
		{ "Dcaron", U"\u0044\u030c" },
		{ "Dcirc", U"\u0044\u0302" },
		{ "Dcy", U"\u0414" },
		{ "Ddot", U"\u0044\u0307" },
		{ "Delta", U"\u0394" },
		{ "Dgr", U"\u0394" },
		{ "Dgrave", U"\u0044\u0300" },
		{ "Dmacr", U"\u0044\u0304" },
		{ "Dot", U"\u00a8" },
		{ "DotDot", U"\u20dc" },
		{ "Dstrok", U"\u0110" },
		{ "Dtilde", U"\u0044\u0303" },
		{ "Duml", U"\u0044\u0308" },
		{ "EEacgr", U"\u0389" },
		{ "EEgr", U"\u0397" },
		{ "ENG", U"\u014a" },
		{ "ETH", U"\u00d0" },
		{ "Eacgr", U"\u0388" },
		{ "Eacute", U"\u00c9" },
		{ "Eacute", U"\u0045\u0301" },
		{ "Ebreve", U"\u0045\u0306" },
		{ "Ebring", U"\u0045\u032f" },
		{ "Ecaron", U"\u011a" },
		{ "Ecaron", U"\u0045\u030c" },
		{ "Ecirc", U"\u00ca" },
		{ "Ecirc", U"\u0045\u0302" },
		{ "Ecy", U"\u042d" },
		{ "Edot", U"\u0116" },
		{ "Edot", U"\u0045\u0307" },
		{ "Edotb", U"\u1eb8" },
		{ "Egr", U"\u0395" },
		{ "Egrave", U"\u00c8" },
		{ "Egrave", U"\u0045\u0300" },
		{ "Emacr", U"\u0112" },
		{ "Emacr", U"\u0045\u0304" },
		{ "Eogon", U"\u0118" },
		{ "Epsilon", U"\u0395" },
		{ "Eta", U"\u0397" },
		{ "Etilde", U"\u0045\u0303" },
		{ "Euml", U"\u00cb" },
		{ "Euml", U"\u0045\u0308" },
		{ "Facute", U"\u0046\u0301" },
		{ "Fbreve", U"\u0046\u0306" },
		{ "Fbring", U"\u0046\u032f" },
		{ "Fcaron", U"\u0046\u030c" },
		{ "Fcirc", U"\u0046\u0302" },
		{ "Fcy", U"\u0424" },
		{ "Fdot", U"\u0046\u0307" },
		{ "Fgrave", U"\u0046\u0300" },
		{ "Fmacr", U"\u0046\u0304" },
		{ "Ftilde", U"\u0046\u0303" },
		{ "Fuml", U"\u0046\u0308" },
		{ "GJcy", U"\u0403" },
		{ "Gacute", U"\u0047\u0301" },
		{ "Gamma", U"\u0393" },
		{ "Gbreve", U"\u011e" },
		{ "Gbreve", U"\u0047\u0306" },
		{ "Gbring", U"\u0047\u032f" },
		{ "Gcaron", U"\u0047\u030c" },
		{ "Gcedil", U"\u0122" },
		{ "Gcirc", U"\u011c" },
		{ "Gcirc", U"\u0047\u0302" },
		{ "Gcy", U"\u0413" },
		{ "Gdot", U"\u0120" },
		{ "Gdot", U"\u0047\u0307" },
		{ "Gg", U"\u22d9" },
		{ "Ggr", U"\u0393" },
		{ "Ggrave", U"\u0047\u0300" },
		{ "Gmacr", U"\u0047\u0304" },
		{ "Gt", U"\u226b" },
		{ "Gtilde", U"\u0047\u0303" },
		{ "Guml", U"\u0047\u0308" },
		{ "HARDcy", U"\u042a" },
		{ "Hacute", U"\u0048\u0301" },
		{ "Hbreve", U"\u0048\u0306" },
		{ "Hbring", U"\u0048\u032f" },
		{ "Hcaron", U"\u0048\u030c" },
		{ "Hcirc", U"\u0124" },
		{ "Hcirc", U"\u0048\u0302" },
		{ "Hdot", U"\u0048\u0307" },
		{ "Hgrave", U"\u0048\u0300" },
		{ "Hmacr", U"\u0048\u0304" },
		{ "Hstrok", U"\u0126" },
		{ "Htilde", U"\u0048\u0303" },
		{ "Huml", U"\u0048\u0308" },
		{ "IEcy", U"\u0415" },
		{ "IJlig", U"\u0132" },
		{ "IOcy", U"\u0401" },
		{ "Iacgr", U"\u038a" },
		{ "Iacute", U"\u00cd" },
		{ "Iacute", U"\u0049\u0301" },
		{ "Ibreve", U"\u0049\u0306" },
		{ "Ibring", U"\u0049\u032f" },
		{ "Icaron", U"\u0049\u030c" },
		{ "Icirc", U"\u00ce" },
		{ "Icirc", U"\u0049\u0302" },
		{ "Icy", U"\u0418" },
		{ "Idigr", U"\u03aa" },
		{ "Idot", U"\u0130" },
		{ "Idot", U"\u0049\u0307" },
		{ "Igr", U"\u0399" },
		{ "Igrave", U"\u00cc" },
		{ "Igrave", U"\u0049\u0300" },
		{ "Imacr", U"\u012a" },
		{ "Imacr", U"\u0049\u0304" },
		{ "Iogon", U"\u012e" },
		{ "Iota", U"\u0399" },
		{ "Itilde", U"\u0128" },
		{ "Itilde", U"\u0049\u0303" },
		{ "Iukcy", U"\u0406" },
		{ "Iuml", U"\u00cf" },
		{ "Iuml", U"\u0049\u0308" },
		{ "Jacute", U"\u004a\u0301" },
		{ "Jbreve", U"\u004a\u0306" },
		{ "Jbring", U"\u004a\u032f" },
		{ "Jcaron", U"\u004a\u030c" },
		{ "Jcirc", U"\u0134" },
		{ "Jcirc", U"\u004a\u0302" },
		{ "Jcy", U"\u0419" },
		{ "Jdot", U"\u004a\u0307" },
		{ "Jgrave", U"\u004a\u0300" },
		{ "Jmacr", U"\u004a\u0304" },
		{ "Jsercy", U"\u0408" },
		{ "Jtilde", U"\u004a\u0303" },
		{ "Jukcy", U"\u0404" },
		{ "Juml", U"\u004a\u0308" },
		{ "KHcy", U"\u0425" },
		{ "KHgr", U"\u03a7" },
		{ "KJcy", U"\u040c" },
		{ "Kacute", U"\u004b\u0301" },
		{ "Kappa", U"\u039a" },
		{ "Kbreve", U"\u004b\u0306" },
		{ "Kbring", U"\u004b\u032f" },
		{ "Kcaron", U"\u004b\u030c" },
		{ "Kcedil", U"\u0136" },
		{ "Kcirc", U"\u004b\u0302" },
		{ "Kcy", U"\u041a" },
		{ "Kdot", U"\u004b\u0307" },
		{ "Kgr", U"\u039a" },
		{ "Kgrave", U"\u004b\u0300" },
		{ "Kmacr", U"\u004b\u0304" },
		{ "Ktilde", U"\u004b\u0303" },
		{ "Kuml", U"\u004b\u0308" },
		{ "LJcy", U"\u0409" },
		{ "Lacute", U"\u0139" },
		{ "Lacute", U"\u004c\u0301" },
		{ "Lambda", U"\u039b" },
		{ "Larr", U"\u219e" },
		{ "Lbreve", U"\u004c\u0306" },
		{ "Lbring", U"\u004c\u032f" },
		{ "Lcaron", U"\u013d" },
		{ "Lcaron", U"\u004c\u030c" },
		{ "Lcedil", U"\u013b" },
		{ "Lcirc", U"\u004c\u0302" },
		{ "Lcy", U"\u041b" },
		{ "Ldot", U"\u004c\u0307" },
		{ "Lgr", U"\u039b" },
		{ "Lgrave", U"\u004c\u0300" },
		{ "Ll", U"\u22d8" },
		{ "Lmacr", U"\u004c\u0304" },
		{ "Lmidot", U"\u013f" },
		{ "Lstrok", U"\u0141" },
		{ "Lt", U"\u226a" },
		{ "Ltilde", U"\u004c\u0303" },
		{ "Luml", U"\u004c\u0308" },
		{ "Macute", U"\u004d\u0301" },
		{ "Mbreve", U"\u004d\u0306" },
		{ "Mbring", U"\u004d\u032f" },
		{ "Mcaron", U"\u004d\u030c" },
		{ "Mcirc", U"\u004d\u0302" },
		{ "Mcy", U"\u041c" },
		{ "Mdot", U"\u004d\u0307" },
		{ "Mgr", U"\u039c" },
		{ "Mgrave", U"\u004d\u0300" },
		{ "Mmacr", U"\u004d\u0304" },
		{ "Mtilde", U"\u004d\u0303" },
		{ "Mu", U"\u039c" },
		{ "Muml", U"\u004d\u0308" },
		{ "NJcy", U"\u040a" },
		{ "Nacute", U"\u0143" },
		{ "Nacute", U"\u004e\u0301" },
		{ "Nbreve", U"\u004e\u0306" },
		{ "Nbring", U"\u004e\u032f" },
		{ "Ncaron", U"\u0147" },
		{ "Ncaron", U"\u004e\u030c" },
		{ "Ncedil", U"\u0145" },
		{ "Ncirc", U"\u004e\u0302" },
		{ "Ncy", U"\u041d" },
		{ "Ndot", U"\u004e\u0307" },
		{ "Ngr", U"\u039d" },
		{ "Ngrave", U"\u004e\u0300" },
		{ "Nmacr", U"\u004e\u0304" },
		{ "Ntilde", U"\u00d1" },
		{ "Ntilde", U"\u004e\u0303" },
		{ "Nu", U"\u039d" },
		{ "Numl", U"\u004e\u0308" },
		{ "OElig", U"\u0152" },
		{ "OHacgr", U"\u038f" },
		{ "OHgr", U"\u03a9" },
		{ "Oacgr", U"\u038c" },
		{ "Oacute", U"\u00d3" },
		{ "Oacute", U"\u004f\u0301" },
		{ "Obreve", U"\u004f\u0306" },
		{ "Obring", U"\u004f\u032f" },
		{ "Ocaron", U"\u01d1" },
		{ "Ocaron", U"\u004f\u030c" },
		{ "Ocirc", U"\u00d4" },
		{ "Ocirc", U"\u004f\u0302" },
		{ "Ocy", U"\u041e" },
		{ "Odblac", U"\u0150" },
		{ "Odot", U"\u004f\u0307" },
		{ "Odotb", U"\u1ecc" },
		{ "Ogr", U"\u039f" },
		{ "Ograve", U"\u00d2" },
		{ "Ograve", U"\u004f\u0300" },
		{ "Omacr", U"\u014c" },
		{ "Omacr", U"\u004f\u0304" },
		{ "Omega", U"\u03a9" },
		{ "Omicron", U"\u039f" },
		{ "Oslash", U"\u00d8" },
		{ "Otilde", U"\u00d5" },
		{ "Otilde", U"\u004f\u0303" },
		{ "Ouml", U"\u00d6" },
		{ "Ouml", U"\u004f\u0308" },
		{ "PHgr", U"\u03a6" },
		{ "PSgr", U"\u03a8" },
		{ "Pacute", U"\u0050\u0301" },
		{ "Pbreve", U"\u0050\u0306" },
		{ "Pbring", U"\u0050\u032f" },
		{ "Pcaron", U"\u0050\u030c" },
		{ "Pcirc", U"\u0050\u0302" },
		{ "Pcy", U"\u041f" },
		{ "Pdot", U"\u0050\u0307" },
		{ "Pgr", U"\u03a0" },
		{ "Pgrave", U"\u0050\u0300" },
		{ "Phi", U"\u03a6" },
		{ "Pi", U"\u03a0" },
		{ "Pmacr", U"\u0050\u0304" },
		{ "Prime", U"\u2033" },
		{ "Psi", U"\u03a8" },
		{ "Ptilde", U"\u0050\u0303" },
		{ "Puml", U"\u0050\u0308" },
		{ "Qacute", U"\u0051\u0301" },
		{ "Qbreve", U"\u0051\u0306" },
		{ "Qbring", U"\u0051\u032f" },
		{ "Qcaron", U"\u0051\u030c" },
		{ "Qcirc", U"\u0051\u0302" },
		{ "Qdot", U"\u0051\u0307" },
		{ "Qgrave", U"\u0051\u0300" },
		{ "Qmacr", U"\u0051\u0304" },
		{ "Qtilde", U"\u0051\u0303" },
		{ "Quml", U"\u0051\u0308" },
		{ "Racute", U"\u0154" },
		{ "Racute", U"\u0052\u0301" },
		{ "Rarr", U"\u21a0" },
		{ "Rbreve", U"\u0052\u0306" },
		{ "Rbring", U"\u0052\u032f" },
		{ "Rcaron", U"\u0158" },
		{ "Rcaron", U"\u0052\u030c" },
		{ "Rcedil", U"\u0156" },
		{ "Rcirc", U"\u0052\u0302" },
		{ "Rcy", U"\u0420" },
		{ "Rdot", U"\u0052\u0307" },
		{ "Rgr", U"\u03a1" },
		{ "Rgrave", U"\u0052\u0300" },
		{ "Rho", U"\u03a1" },
		{ "Rmacr", U"\u0052\u0304" },
		{ "Rtilde", U"\u0052\u0303" },
		{ "Ruml", U"\u0052\u0308" },
		{ "SHCHcy", U"\u0429" },
		{ "SHcy", U"\u0428" },
		{ "SOFTcy", U"\u042c" },
		{ "Sacute", U"\u015a" },
		{ "Sacute", U"\u0053\u0301" },
		{ "Sbreve", U"\u0053\u0306" },
		{ "Sbring", U"\u0053\u032f" },
		{ "Scaron", U"\u0160" },
		{ "Scaron", U"\u0053\u030c" },
		{ "Scedil", U"\u015e" },
		{ "Scirc", U"\u015c" },
		{ "Scirc", U"\u0053\u0302" },
		{ "Scy", U"\u0421" },
		{ "Sdot", U"\u0053\u0307" },
		{ "Sgr", U"\u03a3" },
		{ "Sgrave", U"\u0053\u0300" },
		{ "Sigma", U"\u03a3" },
		{ "Smacr", U"\u0053\u0304" },
		{ "Stilde", U"\u0053\u0303" },
		{ "Sub", U"\u22d0" },
		{ "Suml", U"\u0053\u0308" },
		{ "Sup", U"\u22d1" },
		{ "THORN", U"\u00de" },
		{ "THgr", U"\u0398" },
		{ "TSHcy", U"\u040b" },
		{ "TScy", U"\u0426" },
		{ "Tacute", U"\u0054\u0301" },
		{ "Tau", U"\u03a4" },
		{ "Tbreve", U"\u0054\u0306" },
		{ "Tbring", U"\u0054\u032f" },
		{ "Tcaron", U"\u0164" },
		{ "Tcaron", U"\u0054\u030c" },
		{ "Tcedil", U"\u0162" },
		{ "Tcirc", U"\u0054\u0302" },
		{ "Tcy", U"\u0422" },
		{ "Tdot", U"\u0054\u0307" },
		{ "Tgr", U"\u03a4" },
		{ "Tgrave", U"\u0054\u0300" },
		{ "Theta", U"\u0398" },
		{ "Tmacr", U"\u0054\u0304" },
		{ "Tstrok", U"\u0166" },
		{ "Ttilde", U"\u0054\u0303" },
		{ "Tuml", U"\u0054\u0308" },
		{ "Uacgr", U"\u038e" },
		{ "Uacute", U"\u00da" },
		{ "Uacute", U"\u0055\u0301" },
		{ "Ubrcy", U"\u040e" },
		{ "Ubreve", U"\u016c" },
		{ "Ubreve", U"\u0055\u0306" },
		{ "Ubring", U"\u0055\u032f" },
		{ "Ucaron", U"\u0055\u030c" },
		{ "Ucirc", U"\u00db" },
		{ "Ucirc", U"\u0055\u0302" },
		{ "Ucy", U"\u0423" },
		{ "Udblac", U"\u0170" },
		{ "Udigr", U"\u03ab" },
		{ "Udot", U"\u0055\u0307" },
		{ "Ugr", U"\u03a5" },
		{ "Ugrave", U"\u00d9" },
		{ "Ugrave", U"\u0055\u0300" },
		{ "Umacr", U"\u016a" },
		{ "Umacr", U"\u0055\u0304" },
		{ "Uogon", U"\u0172" },
		{ "Upsi", U"\u03a5" },
		{ "Upsilon", U"\u03a5" },
		{ "Uring", U"\u016e" },
		{ "Utilde", U"\u0168" },
		{ "Utilde", U"\u0055\u0303" },
		{ "Uuml", U"\u00dc" },
		{ "Uuml", U"\u0055\u0308" },
		{ "Vacute", U"\u0056\u0301" },
		{ "Vbreve", U"\u0056\u0306" },
		{ "Vbring", U"\u0056\u032f" },
		{ "Vcaron", U"\u0056\u030c" },
		{ "Vcirc", U"\u0056\u0302" },
		{ "Vcy", U"\u0412" },
		{ "Vdash", U"\u22a9" },
		{ "Vdot", U"\u0056\u0307" },
		{ "Verbar", U"\u2016" },
		{ "Vgrave", U"\u0056\u0300" },
		{ "Vmacr", U"\u0056\u0304" },
		{ "Vtilde", U"\u0056\u0303" },
		{ "Vuml", U"\u0056\u0308" },
		{ "Vvdash", U"\u22aa" },
		{ "Wacute", U"\u0057\u0301" },
		{ "Wbreve", U"\u0057\u0306" },
		{ "Wbring", U"\u0057\u032f" },
		{ "Wcaron", U"\u0057\u030c" },
		{ "Wcirc", U"\u0174" },
		{ "Wcirc", U"\u0057\u0302" },
		{ "Wdot", U"\u0057\u0307" },
		{ "Wgrave", U"\u0057\u0300" },
		{ "Wmacr", U"\u0057\u0304" },
		{ "Wtilde", U"\u0057\u0303" },
		{ "Wuml", U"\u0057\u0308" },
		{ "Xacute", U"\u0058\u0301" },
		{ "Xbreve", U"\u0058\u0306" },
		{ "Xbring", U"\u0058\u032f" },
		{ "Xcaron", U"\u0058\u030c" },
		{ "Xcirc", U"\u0058\u0302" },
		{ "Xdot", U"\u0058\u0307" },
		{ "Xgr", U"\u039e" },
		{ "Xgrave", U"\u0058\u0300" },
		{ "Xi", U"\u039e" },
		{ "Xmacr", U"\u0058\u0304" },
		{ "Xtilde", U"\u0058\u0303" },
		{ "Xuml", U"\u0058\u0308" },
		{ "YAcy", U"\u042f" },
		{ "YIcy", U"\u0407" },
		{ "YUcy", U"\u042e" },
		{ "Yacute", U"\u00dd" },
		{ "Yacute", U"\u0059\u0301" },
		{ "Ybreve", U"\u0059\u0306" },
		{ "Ybring", U"\u0059\u032f" },
		{ "Ycaron", U"\u0059\u030c" },
		{ "Ycirc", U"\u0176" },
		{ "Ycirc", U"\u0059\u0302" },
		{ "Ycy", U"\u042b" },
		{ "Ydot", U"\u0059\u0307" },
		{ "Ygrave", U"\u0059\u0300" },
		{ "Ymacr", U"\u0059\u0304" },
		{ "Ytilde", U"\u0059\u0303" },
		{ "Yuml", U"\u0178" },
		{ "Yuml", U"\u0059\u0308" },
		{ "ZHcy", U"\u0416" },
		{ "Zacute", U"\u0179" },
		{ "Zacute", U"\u005a\u0301" },
		{ "Zbreve", U"\u005a\u0306" },
		{ "Zbring", U"\u005a\u032f" },
		{ "Zcaron", U"\u017d" },
		{ "Zcaron", U"\u005a\u030c" },
		{ "Zcirc", U"\u005a\u0302" },
		{ "Zcy", U"\u0417" },
		{ "Zdot", U"\u017b" },
		{ "Zdot", U"\u005a\u0307" },
		{ "Zeta", U"\u0396" },
		{ "Zgr", U"\u0396" },
		{ "Zgrave", U"\u005a\u0300" },
		{ "Zmacr", U"\u005a\u0304" },
		{ "Ztilde", U"\u005a\u0303" },
		{ "Zuml", U"\u005a\u0308" },
		{ "aacgr", U"\u03ac" },
		{ "aacute", U"\u00e1" },
		{ "aacute", U"\u0061\u0301" },
		{ "abreve", U"\u0103" },
		{ "abreve", U"\u0061\u0306" },
		{ "abring", U"\u0061\u032f" },
		{ "acaron", U"\u0061\u030c" },
		{ "acirc", U"\u00e2" },
		{ "acirc", U"\u0061\u0302" },
		{ "acute", U"\u00b4" },
		{ "acy", U"\u0430" },
		{ "adot", U"\u0061\u0307" },
		{ "aelig", U"\u00e6" },
		{ "agr", U"\u03b1" },
		{ "agrave", U"\u00e0" },
		{ "agrave", U"\u0061\u0300" },
		{ "alefsym", U"\u2135" },
		{ "aleph", U"\u2135" },
		{ "alpha", U"\u03b1" },
		{ "amacr", U"\u0101" },
		{ "amacr", U"\u0061\u0304" },
		{ "amalg", U"\u2210" },
		{ "amp", U"\u0026" },
		{ "and", U"\u2227" },
		{ "ang", U"\u2220" },
		{ "ang90", U"\u221f" },
		{ "angmsd", U"\u2221" },
		{ "angsph", U"\u2222" },
		{ "angst", U"\u212b" },
		{ "aogon", U"\u0105" },
		{ "ap", U"\u2248" },
		{ "ape", U"\u224a" },
		{ "apos", U"\u0027" },
		{ "apos", U"\u02bc" },
		{ "aring", U"\u00e5" },
		{ "ast", U"\u002a" },
		{ "asymp", U"\u2248" },
		{ "atilde", U"\u00e3" },
		{ "atilde", U"\u0061\u0303" },
		{ "auml", U"\u00e4" },
		{ "auml", U"\u0061\u0308" },
		{ "b.Delta", U"\u0394" },
		{ "b.Gamma", U"\u0393" },
		{ "b.Lambda", U"\u039b" },
		{ "b.Omega", U"\u03a9" },
		{ "b.Phi", U"\u03a6" },
		{ "b.Pi", U"\u03a0" },
		{ "b.Psi", U"\u03a8" },
		{ "b.Sigma", U"\u03a3" },
		{ "b.Theta", U"\u0398" },
		{ "b.Upsi", U"\u03a5" },
		{ "b.Xi", U"\u039e" },
		{ "b.alpha", U"\u03b1" },
		{ "b.beta", U"\u03b2" },
		{ "b.chi", U"\u03c7" },
		{ "b.delta", U"\u03b4" },
		{ "b.epsi", U"\u03b5" },
		{ "b.epsis", U"\u03b5" },
		{ "b.epsiv", U"\u03b5" },
		{ "b.eta", U"\u03b7" },
		{ "b.gamma", U"\u03b3" },
		{ "b.gammad", U"\u03dc" },
		{ "b.iota", U"\u03b9" },
		{ "b.kappa", U"\u03ba" },
		{ "b.kappav", U"\u03f0" },
		{ "b.lambda", U"\u03bb" },
		{ "b.mu", U"\u03bc" },
		{ "b.nu", U"\u03bd" },
		{ "b.omega", U"\u03ce" },
		{ "b.phis", U"\u03c6" },
		{ "b.phiv", U"\u03d5" },
		{ "b.pi", U"\u03c0" },
		{ "b.piv", U"\u03d6" },
		{ "b.psi", U"\u03c8" },
		{ "b.rho", U"\u03c1" },
		{ "b.rhov", U"\u03f1" },
		{ "b.sigma", U"\u03c3" },
		{ "b.sigmav", U"\u03c2" },
		{ "b.tau", U"\u03c4" },
		{ "b.thetas", U"\u03b8" },
		{ "b.thetav", U"\u03d1" },
		{ "b.upsi", U"\u03c5" },
		{ "b.xi", U"\u03be" },
		{ "b.zeta", U"\u03b6" },
		{ "bacute", U"\u0062\u0301" },
		{ "barwed", U"\u22bc" },
		{ "bbreve", U"\u0062\u0306" },
		{ "bbring", U"\u0062\u032f" },
		{ "bcaron", U"\u0062\u030c" },
		{ "bcirc", U"\u0062\u0302" },
		{ "bcong", U"\u224c" },
		{ "bcy", U"\u0431" },
		{ "bdot", U"\u0062\u0307" },
		{ "bdquo", U"\u201e" },
		{ "becaus", U"\u2235" },
		{ "bepsi", U"\u220d" },
		{ "bernou", U"\u212c" },
		{ "beta", U"\u03b2" },
		{ "beth", U"\u2136" },
		{ "bgr", U"\u03b2" },
		{ "bgrave", U"\u0062\u0300" },
		{ "blank", U"\u2423" },
		{ "blk12", U"\u2592" },
		{ "blk14", U"\u2591" },
		{ "blk34", U"\u2593" },
		{ "block", U"\u2588" },
		{ "bmacr", U"\u0062\u0304" },
		{ "bottom", U"\u22a5" },
		{ "bowtie", U"\u22c8" },
		{ "boxDL", U"\u2557" },
		{ "boxDR", U"\u2554" },
		{ "boxDl", U"\u2556" },
		{ "boxDr", U"\u2553" },
		{ "boxH", U"\u2550" },
		{ "boxHD", U"\u2566" },
		{ "boxHU", U"\u2569" },
		{ "boxHd", U"\u2564" },
		{ "boxHu", U"\u2567" },
		{ "boxUL", U"\u255d" },
		{ "boxUR", U"\u255a" },
		{ "boxUl", U"\u255c" },
		{ "boxUr", U"\u2559" },
		{ "boxV", U"\u2551" },
		{ "boxVH", U"\u256c" },
		{ "boxVL", U"\u2563" },
		{ "boxVR", U"\u2560" },
		{ "boxVh", U"\u256b" },
		{ "boxVl", U"\u2562" },
		{ "boxVr", U"\u255f" },
		{ "boxdL", U"\u2555" },
		{ "boxdR", U"\u2552" },
		{ "boxdl", U"\u2510" },
		{ "boxdr", U"\u250c" },
		{ "boxh", U"\u2500" },
		{ "boxhD", U"\u2565" },
		{ "boxhU", U"\u2568" },
		{ "boxhd", U"\u252c" },
		{ "boxhu", U"\u2534" },
		{ "boxuL", U"\u255b" },
		{ "boxuR", U"\u2558" },
		{ "boxul", U"\u2518" },
		{ "boxur", U"\u2514" },
		{ "boxv", U"\u2502" },
		{ "boxvH", U"\u256a" },
		{ "boxvL", U"\u2561" },
		{ "boxvR", U"\u255e" },
		{ "boxvh", U"\u253c" },
		{ "boxvl", U"\u2524" },
		{ "boxvr", U"\u251c" },
		{ "bprime", U"\u2035" },
		{ "breve", U"\u02d8" },
		{ "brvbar", U"\u00a6" },
		{ "bsim", U"\u223d" },
		{ "bsime", U"\u22cd" },
		{ "bsol", U"\u005c" },
		{ "btilde", U"\u0062\u0303" },
		{ "bull", U"\u2022" },
		{ "buml", U"\u0062\u0308" },
		{ "bump", U"\u224e" },
		{ "bumpe", U"\u224f" },
		{ "cacute", U"\u0107" },
		{ "cacute", U"\u0063\u0301" },
		{ "cap", U"\u2229" },
		{ "caret", U"\u2041" },
		{ "caron", U"\u02c7" },
		{ "cbreve", U"\u0063\u0306" },
		{ "cbring", U"\u0063\u032f" },
		{ "ccaron", U"\u010d" },
		{ "ccaron", U"\u0063\u030c" },
		{ "ccedil", U"\u00e7" },
		{ "ccirc", U"\u0109" },
		{ "ccirc", U"\u0063\u0302" },
		{ "cdot", U"\u010b" },
		{ "cdot", U"\u0063\u0307" },
		{ "cedil", U"\u00b8" },
		{ "cent", U"\u00a2" },
		{ "cgrave", U"\u0063\u0300" },
		{ "chcy", U"\u0447" },
		{ "check", U"\u2713" },
		{ "chi", U"\u03c7" },
		{ "cir", U"\u25cb" },
		{ "circ", U"\u02c6" },
		{ "circlef", U"\u25cf" },
		{ "circlefb", U"\u25d2" },
		{ "circlefl", U"\u25d0" },
		{ "circlefr", U"\u25d1" },
		{ "circleft", U"\u25d3" },
		{ "cire", U"\u2257" },
		{ "clubs", U"\u2663" },
		{ "cmacr", U"\u0063\u0304" },
		{ "colon", U"\u003a" },
		{ "colone", U"\u2254" },
		{ "comma", U"\u002c" },
		{ "commat", U"\u0040" },
		{ "comp", U"\u2201" },
		{ "compfn", U"\u2218" },
		{ "cong", U"\u2245" },
		{ "conint", U"\u222e" },
		{ "coprod", U"\u2210" },
		{ "copy", U"\u00a9" },
		{ "copysr", U"\u2117" },
		{ "crarr", U"\u21b5" },
		{ "cross", U"\u2717" },
		{ "ctilde", U"\u0063\u0303" },
		{ "cuepr", U"\u22de" },
		{ "cuesc", U"\u22df" },
		{ "cularr", U"\u21b6" },
		{ "cuml", U"\u0063\u0308" },
		{ "cup", U"\u222a" },
		{ "cupre", U"\u227c" },
		{ "curarr", U"\u21b7" },
		{ "curren", U"\u00a4" },
		{ "cuvee", U"\u22ce" },
		{ "cuwed", U"\u22cf" },
		{ "dArr", U"\u21d3" },
		{ "dacute", U"\u0064\u0301" },
		{ "dagger", U"\u2020" },
		{ "daleth", U"\u2138" },
		{ "darr", U"\u2193" },
		{ "darr2", U"\u21ca" },
		{ "dash", U"\u2010" },
		{ "dashv", U"\u22a3" },
		{ "dblac", U"\u02dd" },
		{ "dbreve", U"\u0064\u0306" },
		{ "dbring", U"\u0064\u032f" },
		{ "dcaron", U"\u010f" },
		{ "dcaron", U"\u0064\u030c" },
		{ "dcirc", U"\u0064\u0302" },
		{ "dcy", U"\u0434" },
		{ "ddot", U"\u0064\u0307" },
		{ "deg", U"\u00b0" },
		{ "delta", U"\u03b4" },
		{ "dgr", U"\u03b4" },
		{ "dgrave", U"\u0064\u0300" },
		{ "dharl", U"\u21c3" },
		{ "dharr", U"\u21c2" },
		{ "diam", U"\u22c4" },
		{ "diamondf", U"\u25c6" },
		{ "diams", U"\u2666" },
		{ "die", U"\u00a8" },
		{ "divide", U"\u00f7" },
		{ "divonx", U"\u22c7" },
		{ "djcy", U"\u0452" },
		{ "dlarr", U"\u2199" },
		{ "dlcorn", U"\u231e" },
		{ "dlcrop", U"\u230d" },
		{ "dmacr", U"\u0064\u0304" },
		{ "dollar", U"\u0024" },
		{ "dot", U"\u02d9" },
		{ "drarr", U"\u2198" },
		{ "drcorn", U"\u231f" },
		{ "drcrop", U"\u230c" },
		{ "dscy", U"\u0455" },
		{ "dstrok", U"\u0111" },
		{ "dtilde", U"\u0064\u0303" },
		{ "dtri", U"\u25bf" },
		{ "dtrif", U"\u25be" },
		{ "duml", U"\u0064\u0308" },
		{ "dzcy", U"\u045f" },
		{ "eDot", U"\u2251" },
		{ "eacgr", U"\u03ad" },
		{ "eacute", U"\u00e9" },
		{ "eacute", U"\u0065\u0301" },
		{ "ebreve", U"\u0065\u0306" },
		{ "ebring", U"\u0065\u032f" },
		{ "ecaron", U"\u011b" },
		{ "ecaron", U"\u0065\u030c" },
		{ "ecir", U"\u2256" },
		{ "ecirc", U"\u00ea" },
		{ "ecirc", U"\u0065\u0302" },
		{ "ecolon", U"\u2255" },
		{ "ecy", U"\u044d" },
		{ "edot", U"\u0117" },
		{ "edot", U"\u0065\u0307" },
		{ "edotb", U"\u1eb9" },
		{ "eeacgr", U"\u03ae" },
		{ "eegr", U"\u03b7" },
		{ "efDot", U"\u2252" },
		{ "egr", U"\u03b5" },
		{ "egrave", U"\u00e8" },
		{ "egrave", U"\u0065\u0300" },
		{ "egs", U"\u22dd" },
		{ "ell", U"\u2113" },
		{ "els", U"\u22dc" },
		{ "emacr", U"\u0113" },
		{ "emacr", U"\u0065\u0304" },
		{ "empty", U"\u2205" },
		{ "emsp", U"\u2003" },
		{ "emsp13", U"\u2004" },
		{ "emsp14", U"\u2005" },
		{ "eng", U"\u014b" },
		{ "ensp", U"\u2002" },
		{ "eogon", U"\u0119" },
		{ "epsi", U"\u03b5" },
		{ "epsilon", U"\u03b5" },
		{ "epsis", U"\u220a" },
		{ "equals", U"\u003d" },
		{ "equiv", U"\u2261" },
		{ "erDot", U"\u2253" },
		{ "esdot", U"\u2250" },
		{ "eta", U"\u03b7" },
		{ "eth", U"\u00f0" },
		{ "etilde", U"\u0065\u0303" },
		{ "euml", U"\u00eb" },
		{ "euml", U"\u0065\u0308" },
		{ "euro", U"\u20ac" },
		{ "excl", U"\u0021" },
		{ "exist", U"\u2203" },
		{ "facute", U"\u0066\u0301" },
		{ "fbreve", U"\u0066\u0306" },
		{ "fbring", U"\u0066\u032f" },
		{ "fcaron", U"\u0066\u030c" },
		{ "fcirc", U"\u0066\u0302" },
		{ "fcy", U"\u0444" },
		{ "fdot", U"\u0066\u0307" },
		{ "female", U"\u2640" },
		{ "ffilig", U"\ufb03" },
		{ "fflig", U"\ufb00" },
		{ "ffllig", U"\ufb04" },
		{ "fgrave", U"\u0066\u0300" },
		{ "filig", U"\ufb01" },
		{ "flat", U"\u266d" },
		{ "fllig", U"\ufb02" },
		{ "fmacr", U"\u0066\u0304" },
		{ "fnof", U"\u0192" },
		{ "forall", U"\u2200" },
		{ "fork", U"\u22d4" },
		{ "frac12", U"\u00bd" },
		{ "frac13", U"\u2153" },
		{ "frac14", U"\u00bc" },
		{ "frac15", U"\u2155" },
		{ "frac16", U"\u2159" },
		{ "frac18", U"\u215b" },
		{ "frac23", U"\u2154" },
		{ "frac25", U"\u2156" },
		{ "frac34", U"\u00be" },
		{ "frac35", U"\u2157" },
		{ "frac38", U"\u215c" },
		{ "frac45", U"\u2158" },
		{ "frac56", U"\u215a" },
		{ "frac58", U"\u215d" },
		{ "frac78", U"\u215e" },
		{ "frasl", U"\u2044" },
		{ "frown", U"\u2322" },
		{ "ftilde", U"\u0066\u0303" },
		{ "fuml", U"\u0066\u0308" },
		{ "gE", U"\u2267" },
		{ "gacute", U"\u01f5" },
		{ "gacute", U"\u0067\u0301" },
		{ "gamma", U"\u03b3" },
		{ "gammad", U"\u03dc" },
		{ "gbreve", U"\u011f" },
		{ "gbreve", U"\u0067\u0306" },
		{ "gbring", U"\u0067\u032f" },
		{ "gcaron", U"\u0067\u030c" },
		{ "gcedil", U"\u0123" },
		{ "gcirc", U"\u011d" },
		{ "gcirc", U"\u0067\u0302" },
		{ "gcy", U"\u0433" },
		{ "gdot", U"\u0121" },
		{ "gdot", U"\u0067\u0307" },
		{ "ge", U"\u2265" },
		{ "gel", U"\u22db" },
		{ "ges", U"\u2265" },
		{ "ggr", U"\u03b3" },
		{ "ggrave", U"\u0067\u0300" },
		{ "gimel", U"\u2137" },
		{ "gjcy", U"\u0453" },
		{ "gl", U"\u2277" },
		{ "gmacr", U"\u0067\u0304" },
		{ "gnE", U"\u2269" },
		{ "gne", U"\u2269" },
		{ "gnsim", U"\u22e7" },
		{ "grave", U"\u0060" },
		{ "gsdot", U"\u22d7" },
		{ "gsim", U"\u2273" },
		{ "gt", U"\u003e" },
		{ "gtilde", U"\u0067\u0303" },
		{ "guml", U"\u0067\u0308" },
		{ "gvnE", U"\u2269" },
		{ "hArr", U"\u21d4" },
		{ "hacute", U"\u0068\u0301" },
		{ "hairsp", U"\u200a" },
		{ "half", U"\u00bd" },
		{ "hamilt", U"\u210b" },
		{ "hardcy", U"\u044a" },
		{ "harr", U"\u2194" },
		{ "harrw", U"\u21ad" },
		{ "hbreve", U"\u0068\u0306" },
		{ "hbring", U"\u0068\u032f" },
		{ "hcaron", U"\u0068\u030c" },
		{ "hcirc", U"\u0125" },
		{ "hcirc", U"\u0068\u0302" },
		{ "hdot", U"\u0068\u0307" },
		{ "hearts", U"\u2665" },
		{ "hellip", U"\u2026" },
		{ "hgrave", U"\u0068\u0300" },
		{ "hmacr", U"\u0068\u0304" },
		{ "horbar", U"\u2015" },
		{ "hstrok", U"\u0127" },
		{ "htilde", U"\u0068\u0303" },
		{ "huml", U"\u0068\u0308" },
		{ "hybull", U"\u2043" },
		{ "hyphen", U"\u002d" },
		{ "iacgr", U"\u03af" },
		{ "iacute", U"\u00ed" },
		{ "iacute", U"\u0069\u0301" },
		{ "ibreve", U"\u0069\u0306" },
		{ "ibring", U"\u0069\u032f" },
		{ "icaron", U"\u0069\u030c" },
		{ "icirc", U"\u00ee" },
		{ "icirc", U"\u0069\u0302" },
		{ "icy", U"\u0438" },
		{ "idiagr", U"\u0390" },
		{ "idigr", U"\u03ca" },
		{ "idot", U"\u0069\u0307" },
		{ "iecy", U"\u0435" },
		{ "iexcl", U"\u00a1" },
		{ "iff", U"\u21d4" },
		{ "igr", U"\u03b9" },
		{ "igrave", U"\u00ec" },
		{ "igrave", U"\u0069\u0300" },
		{ "ijlig", U"\u0133" },
		{ "imacr", U"\u012b" },
		{ "imacr", U"\u0069\u0304" },
		{ "image", U"\u2111" },
		{ "incare", U"\u2105" },
		{ "infin", U"\u221e" },
		{ "inodot", U"\u0131" },
		{ "inodot", U"\u0131" },
		{ "int", U"\u222b" },
		{ "intcal", U"\u22ba" },
		{ "iocy", U"\u0451" },
		{ "iogon", U"\u012f" },
		{ "iota", U"\u03b9" },
		{ "iquest", U"\u00bf" },
		{ "isin", U"\u2208" },
		{ "itilde", U"\u0129" },
		{ "itilde", U"\u0069\u0303" },
		{ "iukcy", U"\u0456" },
		{ "iuml", U"\u00ef" },
		{ "iuml", U"\u0069\u0308" },
		{ "jacute", U"\u006a\u0301" },
		{ "jbreve", U"\u006a\u0306" },
		{ "jbring", U"\u006a\u032f" },
		{ "jcaron", U"\u006a\u030c" },
		{ "jcirc", U"\u0135" },
		{ "jcirc", U"\u006a\u0302" },
		{ "jcy", U"\u0439" },
		{ "jdot", U"\u006a\u0307" },
		{ "jgrave", U"\u006a\u0300" },
		{ "jmacr", U"\u006a\u0304" },
		{ "jsercy", U"\u0458" },
		{ "jtilde", U"\u006a\u0303" },
		{ "jukcy", U"\u0454" },
		{ "juml", U"\u006a\u0308" },
		{ "kacute", U"\u006b\u0301" },
		{ "kappa", U"\u03ba" },
		{ "kappav", U"\u03f0" },
		{ "kbreve", U"\u006b\u0306" },
		{ "kbring", U"\u006b\u032f" },
		{ "kcaron", U"\u006b\u030c" },
		{ "kcedil", U"\u0137" },
		{ "kcirc", U"\u006b\u0302" },
		{ "kcy", U"\u043a" },
		{ "kdot", U"\u006b\u0307" },
		{ "kgr", U"\u03ba" },
		{ "kgrave", U"\u006b\u0300" },
		{ "kgreen", U"\u0138" },
		{ "khcy", U"\u0445" },
		{ "khgr", U"\u03c7" },
		{ "kjcy", U"\u045c" },
		{ "kmacr", U"\u006b\u0304" },
		{ "ktilde", U"\u006b\u0303" },
		{ "kuml", U"\u006b\u0308" },
		{ "lAarr", U"\u21da" },
		{ "lArr", U"\u21d0" },
		{ "lE", U"\u2266" },
		{ "lacute", U"\u013a" },
		{ "lacute", U"\u006c\u0301" },
		{ "lagran", U"\u2112" },
		{ "lambda", U"\u03bb" },
		{ "lang", U"\u2329" },
		{ "laquo", U"\u00ab" },
		{ "larr", U"\u2190" },
		{ "larr2", U"\u21c7" },
		{ "larrhk", U"\u21a9" },
		{ "larrlp", U"\u21ab" },
		{ "larrtl", U"\u21a2" },
		{ "lbreve", U"\u006c\u0306" },
		{ "lbring", U"\u006c\u032f" },
		{ "lcaron", U"\u013e" },
		{ "lcaron", U"\u006c\u030c" },
		{ "lcedil", U"\u013c" },
		{ "lceil", U"\u2308" },
		{ "lcirc", U"\u006c\u0302" },
		{ "lcub", U"\u007b" },
		{ "lcy", U"\u043b" },
		{ "ldot", U"\u22d6" },
		{ "ldot", U"\u006c\u0307" },
		{ "ldquo", U"\u201c" },
		{ "ldquor", U"\u201e" },
		{ "le", U"\u2264" },
		{ "leg", U"\u22da" },
		{ "les", U"\u2264" },
		{ "lfloor", U"\u230a" },
		{ "lg", U"\u2276" },
		{ "lgr", U"\u03bb" },
		{ "lgrave", U"\u006c\u0300" },
		{ "lhard", U"\u21bd" },
		{ "lharu", U"\u21bc" },
		{ "lhblk", U"\u2584" },
		{ "ljcy", U"\u0459" },
		{ "lmacr", U"\u006c\u0304" },
		{ "lmidot", U"\u0140" },
		{ "lnE", U"\u2268" },
		{ "lne", U"\u2268" },
		{ "lnsim", U"\u22e6" },
		{ "lowast", U"\u2217" },
		{ "lowbar", U"\u005f" },
		{ "loz", U"\u25ca" },
		{ "loz", U"\u2727" },
		{ "lozf", U"\u2726" },
		{ "lpar", U"\u0028" },
		{ "lrarr2", U"\u21c6" },
		{ "lrhar2", U"\u21cb" },
		{ "lrm", U"\u200e" },
		{ "lsaquo", U"\u2039" },
		{ "lsh", U"\u21b0" },
		{ "lsim", U"\u2272" },
		{ "lsqb", U"\u005b" },
		{ "lsquo", U"\u2018" },
		{ "lsquor", U"\u201a" },
		{ "lstrok", U"\u0142" },
		{ "lt", U"\u003c" },
		{ "lthree", U"\u22cb" },
		{ "ltilde", U"\u006c\u0303" },
		{ "ltimes", U"\u22c9" },
		{ "ltri", U"\u25c3" },
		{ "ltrie", U"\u22b4" },
		{ "ltrif", U"\u25c2" },
		{ "luml", U"\u006c\u0308" },
		{ "lvnE", U"\u2268" },
		{ "macr", U"\u00af" },
		{ "macute", U"\u006d\u0301" },
		{ "male", U"\u2642" },
		{ "malt", U"\u2720" },
		{ "map", U"\u21a6" },
		{ "marker", U"\u25ae" },
		{ "mbreve", U"\u006d\u0306" },
		{ "mbring", U"\u006d\u032f" },
		{ "mcaron", U"\u006d\u030c" },
		{ "mcirc", U"\u006d\u0302" },
		{ "mcy", U"\u043c" },
		{ "mdash", U"\u2014" },
		{ "mdot", U"\u006d\u0307" },
		{ "mgr", U"\u03bc" },
		{ "mgrave", U"\u006d\u0300" },
		{ "micro", U"\u00b5" },
		{ "mid", U"\u2223" },
		{ "middot", U"\u00b7" },
		{ "minus", U"\u2212" },
		{ "minusb", U"\u229f" },
		{ "mldr", U"\u2026" },
		{ "mmacr", U"\u006d\u0304" },
		{ "mnplus", U"\u2213" },
		{ "models", U"\u22a7" },
		{ "mtilde", U"\u006d\u0303" },
		{ "mu", U"\u03bc" },
		{ "mumap", U"\u22b8" },
		{ "muml", U"\u006d\u0308" },
		{ "nVDash", U"\u22af" },
		{ "nVdash", U"\u22ae" },
		{ "nabla", U"\u2207" },
		{ "nacute", U"\u0144" },
		{ "nacute", U"\u006e\u0301" },
		{ "nap", U"\u2249" },
		{ "napos", U"\u0149" },
		{ "natur", U"\u266e" },
		{ "nbreve", U"\u006e\u0306" },
		{ "nbring", U"\u006e\u032f" },
		{ "nbsp", U"\u00a0" },
		{ "ncaron", U"\u0148" },
		{ "ncaron", U"\u006e\u030c" },
		{ "ncedil", U"\u0146" },
		{ "ncirc", U"\u006e\u0302" },
		{ "ncong", U"\u2247" },
		{ "ncy", U"\u043d" },
		{ "ndash", U"\u2013" },
		{ "ndot", U"\u006e\u0307" },
		{ "ne", U"\u2260" },
		{ "nearr", U"\u2197" },
		{ "nequiv", U"\u2262" },
		{ "nexist", U"\u2204" },
		{ "nge", U"\u2271" },
		{ "nges", U"\u2271" },
		{ "ngr", U"\u03bd" },
		{ "ngrave", U"\u006e\u0300" },
		{ "ngt", U"\u226f" },
		{ "nhArr", U"\u21ce" },
		{ "nharr", U"\u21ae" },
		{ "ni", U"\u220b" },
		{ "njcy", U"\u045a" },
		{ "nlArr", U"\u21cd" },
		{ "nlarr", U"\u219a" },
		{ "nldr", U"\u2025" },
		{ "nle", U"\u2270" },
		{ "nles", U"\u2270" },
		{ "nlt", U"\u226e" },
		{ "nltri", U"\u22ea" },
		{ "nltrie", U"\u22ec" },
		{ "nmacr", U"\u006e\u0304" },
		{ "nmid", U"\u2224" },
		{ "not", U"\u00ac" },
		{ "notin", U"\u2209" },
		{ "npar", U"\u2226" },
		{ "npr", U"\u2280" },
		{ "npre", U"\u22e0" },
		{ "nrArr", U"\u21cf" },
		{ "nrarr", U"\u219b" },
		{ "nrtri", U"\u22eb" },
		{ "nrtrie", U"\u22ed" },
		{ "nsc", U"\u2281" },
		{ "nsce", U"\u22e1" },
		{ "nsim", U"\u2241" },
		{ "nsime", U"\u2244" },
		{ "nspar", U"\u2226" },
		{ "nsub", U"\u2284" },
		{ "nsubE", U"\u2288" },
		{ "nsube", U"\u2288" },
		{ "nsup", U"\u2285" },
		{ "nsupE", U"\u2289" },
		{ "nsupe", U"\u2289" },
		{ "ntilde", U"\u00f1" },
		{ "ntilde", U"\u006e\u0303" },
		{ "nu", U"\u03bd" },
		{ "num", U"\u0023" },
		{ "numero", U"\u2116" },
		{ "numl", U"\u006e\u0308" },
		{ "numsp", U"\u2007" },
		{ "nvDash", U"\u22ad" },
		{ "nvdash", U"\u22ac" },
		{ "nwarr", U"\u2196" },
		{ "oS", U"\u24c8" },
		{ "oacgr", U"\u03cc" },
		{ "oacute", U"\u00f3" },
		{ "oacute", U"\u006f\u0301" },
		{ "oast", U"\u229b" },
		{ "obreve", U"\u006f\u0306" },
		{ "obring", U"\u006f\u032f" },
		{ "ocaron", U"\u01d2" },
		{ "ocaron", U"\u006f\u030c" },
		{ "ocir", U"\u229a" },
		{ "ocirc", U"\u00f4" },
		{ "ocirc", U"\u006f\u0302" },
		{ "ocy", U"\u043e" },
		{ "odash", U"\u229d" },
		{ "odblac", U"\u0151" },
		{ "odot", U"\u2299" },
		{ "odot", U"\u006f\u0307" },
		{ "odotb", U"\u1ecd" },
		{ "oelig", U"\u0153" },
		{ "ogon", U"\u02db" },
		{ "ogr", U"\u03bf" },
		{ "ograve", U"\u00f2" },
		{ "ograve", U"\u006f\u0300" },
		{ "ohacgr", U"\u03ce" },
		{ "ohgr", U"\u03c9" },
		{ "ohm", U"\u2126" },
		{ "olarr", U"\u21ba" },
		{ "oline", U"\u203e" },
		{ "omacr", U"\u014d" },
		{ "omacr", U"\u006f\u0304" },
		{ "omega", U"\u03c9" },
		{ "omicron", U"\u03bf" },
		{ "ominus", U"\u2296" },
		{ "oplus", U"\u2295" },
		{ "or", U"\u2228" },
		{ "orarr", U"\u21bb" },
		{ "order", U"\u2134" },
		{ "ordf", U"\u00aa" },
		{ "ordm", U"\u00ba" },
		{ "oslash", U"\u00f8" },
		{ "osol", U"\u2298" },
		{ "otilde", U"\u00f5" },
		{ "otilde", U"\u006f\u0303" },
		{ "otimes", U"\u2297" },
		{ "ouml", U"\u00f6" },
		{ "ouml", U"\u006f\u0308" },
		{ "pacute", U"\u0070\u0301" },
		{ "page", U"\u000c" },
		{ "par", U"\u2225" },
		{ "para", U"\u00b6" },
		{ "part", U"\u2202" },
		{ "pbreve", U"\u0070\u0306" },
		{ "pbring", U"\u0070\u032f" },
		{ "pcaron", U"\u0070\u030c" },
		{ "pcirc", U"\u0070\u0302" },
		{ "pcy", U"\u043f" },
		{ "pdot", U"\u0070\u0307" },
		{ "percnt", U"\u0025" },
		{ "period", U"\u002e" },
		{ "permil", U"\u2030" },
		{ "perp", U"\u22a5" },
		{ "pgr", U"\u03c0" },
		{ "pgrave", U"\u0070\u0300" },
		{ "phgr", U"\u03c6" },
		{ "phi", U"\u03c6" },
		{ "phis", U"\u03c6" },
		{ "phiv", U"\u03d5" },
		{ "phmmat", U"\u2133" },
		{ "phone", U"\u260e" },
		{ "pi", U"\u03c0" },
		{ "piv", U"\u03d6" },
		{ "planck", U"\u210f" },
		{ "plus", U"\u002b" },
		{ "plusb", U"\u229e" },
		{ "plusdo", U"\u2214" },
		{ "plusmn", U"\u00b1" },
		{ "pmacr", U"\u0070\u0304" },
		{ "pound", U"\u00a3" },
		{ "pr", U"\u227a" },
		{ "pre", U"\u227c" },
		{ "prime", U"\u2032" },
		{ "prnsim", U"\u22e8" },
		{ "prod", U"\u220f" },
		{ "prop", U"\u221d" },
		{ "prsim", U"\u227e" },
		{ "psgr", U"\u03c8" },
		{ "psi", U"\u03c8" },
		{ "ptilde", U"\u0070\u0303" },
		{ "puml", U"\u0070\u0308" },
		{ "puncsp", U"\u2008" },
		{ "qacute", U"\u0071\u0301" },
		{ "qbreve", U"\u0071\u0306" },
		{ "qbring", U"\u0071\u032f" },
		{ "qcaron", U"\u0071\u030c" },
		{ "qcirc", U"\u0071\u0302" },
		{ "qdot", U"\u0071\u0307" },
		{ "qgrave", U"\u0071\u0300" },
		{ "qmacr", U"\u0071\u0304" },
		{ "qtilde", U"\u0071\u0303" },
		{ "quest", U"\u003f" },
		{ "quml", U"\u0071\u0308" },
		{ "quot", U"\u0022" },
		{ "rAarr", U"\u21db" },
		{ "rArr", U"\u21d2" },
		{ "racute", U"\u0155" },
		{ "racute", U"\u0072\u0301" },
		{ "radic", U"\u221a" },
		{ "rang", U"\u232a" },
		{ "raquo", U"\u00bb" },
		{ "rarr", U"\u2192" },
		{ "rarr2", U"\u21c9" },
		{ "rarrhk", U"\u21aa" },
		{ "rarrlp", U"\u21ac" },
		{ "rarrtl", U"\u21a3" },
		{ "rarrw", U"\u219d" },
		{ "rbreve", U"\u0072\u0306" },
		{ "rbring", U"\u0072\u032f" },
		{ "rcaron", U"\u0159" },
		{ "rcaron", U"\u0072\u030c" },
		{ "rcedil", U"\u0157" },
		{ "rceil", U"\u2309" },
		{ "rcirc", U"\u0072\u0302" },
		{ "rcub", U"\u007d" },
		{ "rcy", U"\u0440" },
		{ "rdot", U"\u0072\u0307" },
		{ "rdquo", U"\u201d" },
		{ "rdquor", U"\u201c" },
		{ "real", U"\u211c" },
		{ "rect", U"\u25ad" },
		{ "reg", U"\u00ae" },
		{ "rfloor", U"\u230b" },
		{ "rgr", U"\u03c1" },
		{ "rgrave", U"\u0072\u0300" },
		{ "rhard", U"\u21c1" },
		{ "rharu", U"\u21c0" },
		{ "rho", U"\u03c1" },
		{ "rhov", U"\u03f1" },
		{ "ring", U"\u02da" },
		{ "rlarr2", U"\u21c4" },
		{ "rlhar2", U"\u21cc" },
		{ "rlm", U"\u200f" },
		{ "rmacr", U"\u0072\u0304" },
		{ "rpar", U"\u0029" },
		{ "rsaquo", U"\u203a" },
		{ "rsh", U"\u21b1" },
		{ "rsqb", U"\u005d" },
		{ "rsquo", U"\u2019" },
		{ "rsquor", U"\u2018" },
		{ "rthree", U"\u22cc" },
		{ "rtilde", U"\u0072\u0303" },
		{ "rtimes", U"\u22ca" },
		{ "rtri", U"\u25b9" },
		{ "rtrie", U"\u22b5" },
		{ "rtrif", U"\u25b8" },
		{ "ruml", U"\u0072\u0308" },
		{ "rx", U"\u211e" },
		{ "sacute", U"\u015b" },
		{ "sacute", U"\u0073\u0301" },
		{ "samalg", U"\u2210" },
		{ "sbquo", U"\u201a" },
		{ "sbreve", U"\u0073\u0306" },
		{ "sbring", U"\u0073\u032f" },
		{ "sbsol", U"\u005c" },
		{ "sc", U"\u227b" },
		{ "scaron", U"\u0161" },
		{ "scaron", U"\u0073\u030c" },
		{ "sccue", U"\u227d" },
		{ "sce", U"\u227d" },
		{ "scedil", U"\u015f" },
		{ "schwa", U"\u0259" },
		{ "schwaacute", U"\u0259\u0301" },
		{ "schwadgrave", U"\u0259\u030f" },
		{ "schwagrave", U"\u0259\u0300" },
		{ "schwamacr", U"\u0259\u0304" },
		{ "scirc", U"\u015d" },
		{ "scirc", U"\u0073\u0302" },
		{ "scnsim", U"\u22e9" },
		{ "scsim", U"\u227f" },
		{ "scy", U"\u0441" },
		{ "sdot", U"\u22c5" },
		{ "sdot", U"\u0073\u0307" },
		{ "sdotb", U"\u22a1" },
		{ "sect", U"\u00a7" },
		{ "semi", U"\u003b" },
		{ "setmn", U"\u2216" },
		{ "sext", U"\u2736" },
		{ "sfgr", U"\u03c2" },
		{ "sfrown", U"\u2322" },
		{ "sgr", U"\u03c3" },
		{ "sgrave", U"\u0073\u0300" },
		{ "sharp", U"\u266f" },
		{ "shchcy", U"\u0449" },
		{ "shcy", U"\u0448" },
		{ "shy", U"\u00ad" },
		{ "sigma", U"\u03c3" },
		{ "sigmaf", U"\u03c2" },
		{ "sigmav", U"\u03c2" },
		{ "sim", U"\u223c" },
		{ "sime", U"\u2243" },
		{ "smacr", U"\u0073\u0304" },
		{ "smile", U"\u2323" },
		{ "softcy", U"\u044c" },
		{ "sol", U"\u002f" },
		{ "spades", U"\u2660" },
		{ "spar", U"\u2225" },
		{ "sqcap", U"\u2293" },
		{ "sqcup", U"\u2294" },
		{ "sqsub", U"\u228f" },
		{ "sqsube", U"\u2291" },
		{ "sqsup", U"\u2290" },
		{ "sqsupe", U"\u2292" },
		{ "squ", U"\u25a1" },
		{ "square", U"\u25a1" },
		{ "squarf", U"\u25a0" },
		{ "squf", U"\u25aa" },
		{ "ssetmn", U"\u2216" },
		{ "ssmile", U"\u2323" },
		{ "sstarf", U"\u22c6" },
		{ "star", U"\u2606" },
		{ "starf", U"\u2605" },
		{ "stilde", U"\u0073\u0303" },
		{ "sub", U"\u2282" },
		{ "subE", U"\u2286" },
		{ "sube", U"\u2286" },
		{ "subnE", U"\u228a" },
		{ "subne", U"\u228a" },
		{ "sum", U"\u2211" },
		{ "suml", U"\u0073\u0308" },
		{ "sung", U"\u266a" },
		{ "sup", U"\u2283" },
		{ "sup1", U"\u00b9" },
		{ "sup2", U"\u00b2" },
		{ "sup3", U"\u00b3" },
		{ "supE", U"\u2287" },
		{ "supe", U"\u2287" },
		{ "supnE", U"\u228b" },
		{ "supne", U"\u228b" },
		{ "szlig", U"\u00df" },
		{ "tacute", U"\u0074\u0301" },
		{ "target", U"\u2316" },
		{ "tau", U"\u03c4" },
		{ "tbreve", U"\u0074\u0306" },
		{ "tbring", U"\u0074\u032f" },
		{ "tcaron", U"\u0165" },
		{ "tcaron", U"\u0074\u030c" },
		{ "tcedil", U"\u0163" },
		{ "tcirc", U"\u0074\u0302" },
		{ "tcy", U"\u0442" },
		{ "tdot", U"\u20db" },
		{ "tdot", U"\u0074\u0307" },
		{ "telrec", U"\u2315" },
		{ "tgr", U"\u03c4" },
		{ "tgrave", U"\u0074\u0300" },
		{ "there4", U"\u2234" },
		{ "theta", U"\u03b8" },
		{ "thetas", U"\u03b8" },
		{ "thetasym", U"\u03d1" },
		{ "thetav", U"\u03d1" },
		{ "thgr", U"\u03b8" },
		{ "thinsp", U"\u2009" },
		{ "thkap", U"\u2248" },
		{ "thksim", U"\u223c" },
		{ "thorn", U"\u00fe" },
		{ "tilde", U"\u02dc" },
		{ "times", U"\u00d7" },
		{ "timesb", U"\u22a0" },
		{ "tmacr", U"\u0074\u0304" },
		{ "top", U"\u22a4" },
		{ "tprime", U"\u2034" },
		{ "trade", U"\u2122" },
		{ "trie", U"\u225c" },
		{ "tscy", U"\u0446" },
		{ "tshcy", U"\u045b" },
		{ "tstrok", U"\u0167" },
		{ "ttilde", U"\u0074\u0303" },
		{ "tuml", U"\u0074\u0308" },
		{ "twixt", U"\u226c" },
		{ "uArr", U"\u21d1" },
		{ "uacgr", U"\u03cd" },
		{ "uacute", U"\u00fa" },
		{ "uacute", U"\u0075\u0301" },
		{ "uarr", U"\u2191" },
		{ "uarr2", U"\u21c8" },
		{ "ubrcy", U"\u045e" },
		{ "ubreve", U"\u016d" },
		{ "ubreve", U"\u0075\u0306" },
		{ "ubring", U"\u0075\u032f" },
		{ "ucaron", U"\u0075\u030c" },
		{ "ucirc", U"\u00fb" },
		{ "ucirc", U"\u0075\u0302" },
		{ "ucy", U"\u0443" },
		{ "udblac", U"\u0171" },
		{ "udiagr", U"\u03b0" },
		{ "udigr", U"\u03cb" },
		{ "udot", U"\u0075\u0307" },
		{ "ugr", U"\u03c5" },
		{ "ugrave", U"\u00f9" },
		{ "ugrave", U"\u0075\u0300" },
		{ "uharl", U"\u21bf" },
		{ "uharr", U"\u21be" },
		{ "uhblk", U"\u2580" },
		{ "ulcorn", U"\u231c" },
		{ "ulcrop", U"\u230f" },
		{ "umacr", U"\u016b" },
		{ "umacr", U"\u0075\u0304" },
		{ "uml", U"\u00a8" },
		{ "uogon", U"\u0173" },
		{ "uplus", U"\u228e" },
		{ "upsi", U"\u03c5" },
		{ "upsih", U"\u03d2" },
		{ "upsilon", U"\u03c5" },
		{ "urcorn", U"\u231d" },
		{ "urcrop", U"\u230e" },
		{ "uring", U"\u016f" },
		{ "utilde", U"\u0169" },
		{ "utilde", U"\u0075\u0303" },
		{ "utri", U"\u25b5" },
		{ "utrif", U"\u25b4" },
		{ "uuml", U"\u00fc" },
		{ "uuml", U"\u0075\u0308" },
		{ "vArr", U"\u21d5" },
		{ "vDash", U"\u22a8" },
		{ "vacute", U"\u0076\u0301" },
		{ "varr", U"\u2195" },
		{ "vbreve", U"\u0076\u0306" },
		{ "vbring", U"\u0076\u032f" },
		{ "vcaron", U"\u0076\u030c" },
		{ "vcirc", U"\u0076\u0302" },
		{ "vcy", U"\u0432" },
		{ "vdash", U"\u22a2" },
		{ "vdot", U"\u0076\u0307" },
		{ "veebar", U"\u22bb" },
		{ "vellip", U"\u22ee" },
		{ "verbar", U"\u007c" },
		{ "vgrave", U"\u0076\u0300" },
		{ "vltri", U"\u22b2" },
		{ "vmacr", U"\u0076\u0304" },
		{ "vprime", U"\u2032" },
		{ "vprop", U"\u221d" },
		{ "vrtri", U"\u22b3" },
		{ "vsubnE", U"\u228a" },
		{ "vsubne", U"\u228a" },
		{ "vsupnE", U"\u228b" },
		{ "vsupne", U"\u228b" },
		{ "vtab", U"\u000b" },
		{ "vtilde", U"\u0076\u0303" },
		{ "vuml", U"\u0076\u0308" },
		{ "wacute", U"\u0077\u0301" },
		{ "wbreve", U"\u0077\u0306" },
		{ "wbring", U"\u0077\u032f" },
		{ "wcaron", U"\u0077\u030c" },
		{ "wcirc", U"\u0175" },
		{ "wcirc", U"\u0077\u0302" },
		{ "wdot", U"\u0077\u0307" },
		{ "wedgeq", U"\u2259" },
		{ "weierp", U"\u2118" },
		{ "wgrave", U"\u0077\u0300" },
		{ "wmacr", U"\u0077\u0304" },
		{ "wreath", U"\u2240" },
		{ "wtilde", U"\u0077\u0303" },
		{ "wuml", U"\u0077\u0308" },
		{ "xacute", U"\u0078\u0301" },
		{ "xbreve", U"\u0078\u0306" },
		{ "xbring", U"\u0078\u032f" },
		{ "xcaron", U"\u0078\u030c" },
		{ "xcirc", U"\u25cb" },
		{ "xcirc", U"\u0078\u0302" },
		{ "xdot", U"\u0078\u0307" },
		{ "xdtri", U"\u25bd" },
		{ "xgr", U"\u03be" },
		{ "xgrave", U"\u0078\u0300" },
		{ "xhArr", U"\u2194" },
		{ "xharr", U"\u2194" },
		{ "xi", U"\u03be" },
		{ "xlArr", U"\u21d0" },
		{ "xmacr", U"\u0078\u0304" },
		{ "xrArr", U"\u21d2" },
		{ "xtilde", U"\u0078\u0303" },
		{ "xuml", U"\u0078\u0308" },
		{ "xutri", U"\u25b3" },
		{ "yacute", U"\u00fd" },
		{ "yacute", U"\u0079\u0301" },
		{ "yacy", U"\u044f" },
		{ "ybreve", U"\u0079\u0306" },
		{ "ybring", U"\u0079\u032f" },
		{ "ycaron", U"\u0079\u030c" },
		{ "ycirc", U"\u0177" },
		{ "ycirc", U"\u0079\u0302" },
		{ "ycy", U"\u044b" },
		{ "ydot", U"\u0079\u0307" },
		{ "yen", U"\u00a5" },
		{ "ygrave", U"\u0079\u0300" },
		{ "yicy", U"\u0457" },
		{ "ymacr", U"\u0079\u0304" },
		{ "ytilde", U"\u0079\u0303" },
		{ "yucy", U"\u044e" },
		{ "yuml", U"\u00ff" },
		{ "yuml", U"\u0079\u0308" },
		{ "zacute", U"\u017a" },
		{ "zacute", U"\u007a\u0301" },
		{ "zbreve", U"\u007a\u0306" },
		{ "zbring", U"\u007a\u032f" },
		{ "zcaron", U"\u017e" },
		{ "zcaron", U"\u007a\u030c" },
		{ "zcirc", U"\u007a\u0302" },
		{ "zcy", U"\u0437" },
		{ "zdot", U"\u017c" },
		{ "zdot", U"\u007a\u0307" },
		{ "zeta", U"\u03b6" },
		{ "zgr", U"\u03b6" },
		{ "zgrave", U"\u007a\u0300" },
		{ "zhcy", U"\u0436" },
		{ "zmacr", U"\u007a\u0304" },
		{ "ztilde", U"\u007a\u0303" },
		{ "zuml", U"\u007a\u0308" },
		{ "zwj", U"\u200d" },
		{ "zwnj", U"\u200c" },
	};

	inline const size_t unicode_sgml[] = {
		0x5b6,
		0x48d,
		0x30d,
		0x4c3,
		0x457,
		0x2d2,
		0x497,
		0x1f1,
		0x1fb,
		0x3e6,
		0x4ec,
		0x1fe,
		0x4a6,
		0x29b,
		0x36e,
		0x498,
		0x528,
		0x299,
		0x515,
		0x3f1,
		0x303,
		0x353,
		0x4c1,
		0x29c,
		0xe,
		0x3,
		0x9,
		0x15,
		0x11,
		0x5,
		0xb,
		0x17,
		0x7,
		0x6,
		0x22,
		0x18,
		0x1d,
		0x24,
		0x23,
		0x1a,
		0x1f,
		0x25,
		0x1c,
		0x1b,
		0x33,
		0x28,
		0x30,
		0x36,
		0x35,
		0x2a,
		0x32,
		0x37,
		0x2d,
		0x2b,
		0x47,
		0x3c,
		0x42,
		0x4c,
		0x48,
		0x3e,
		0x44,
		0x4d,
		0x41,
		0x3f,
		0x61,
		0x54,
		0x5a,
		0x67,
		0x63,
		0x55,
		0x5d,
		0x69,
		0x58,
		0x56,
		0x71,
		0x6a,
		0x6e,
		0x73,
		0x72,
		0x6b,
		0x70,
		0x74,
		0x6d,
		0x6c,
		0x84,
		0x76,
		0x7e,
		0x87,
		0x85,
		0x79,
		0x81,
		0x88,
		0x7b,
		0x7a,
		0x91,
		0x8a,
		0x8f,
		0x94,
		0x92,
		0x8b,
		0x90,
		0x95,
		0x8d,
		0x8c,
		0xa7,
		0x9b,
		0xa0,
		0xad,
		0xa9,
		0x9c,
		0xa4,
		0xb0,
		0x9e,
		0x9d,
		0xb9,
		0xb1,
		0xb6,
		0xbc,
		0xba,
		0xb2,
		0xb8,
		0xbe,
		0xb4,
		0xb3,
		0xcc,
		0xc2,
		0xc8,
		0xce,
		0xcd,
		0xc4,
		0xca,
		0xcf,
		0xc6,
		0xc5,
		0xde,
		0xd2,
		0xda,
		0xe4,
		0xe0,
		0xd5,
		0xdc,
		0xe5,
		0xd8,
		0xd6,
		0xee,
		0xe6,
		0xea,
		0xf0,
		0xef,
		0xe7,
		0xec,
		0xf2,
		0xe9,
		0xe8,
		0xff,
		0xf5,
		0xfb,
		0x102,
		0x100,
		0xf6,
		0xfd,
		0x104,
		0xf9,
		0xf7,
		0x117,
		0x10a,
		0x110,
		0x11e,
		0x119,
		0x10b,
		0x113,
		0x120,
		0x10e,
		0x10c,
		0x12b,
		0x123,
		0x127,
		0x131,
		0x12e,
		0x124,
		0x129,
		0x132,
		0x126,
		0x125,
		0x139,
		0x133,
		0x137,
		0x13b,
		0x13a,
		0x134,
		0x138,
		0x13c,
		0x136,
		0x135,
		0x149,
		0x13e,
		0x145,
		0x14c,
		0x14b,
		0x140,
		0x147,
		0x14d,
		0x143,
		0x141,
		0x15d,
		0x152,
		0x159,
		0x160,
		0x15f,
		0x153,
		0x15b,
		0x162,
		0x156,
		0x154,
		0x173,
		0x168,
		0x16f,
		0x177,
		0x175,
		0x16a,
		0x171,
		0x178,
		0x16d,
		0x16b,
		0x189,
		0x17b,
		0x182,
		0x191,
		0x18b,
		0x17e,
		0x186,
		0x193,
		0x180,
		0x17f,
		0x19d,
		0x194,
		0x198,
		0x19f,
		0x19e,
		0x195,
		0x19b,
		0x1a0,
		0x197,
		0x196,
		0x1a9,
		0x1a2,
		0x1a7,
		0x1ab,
		0x1aa,
		0x1a3,
		0x1a8,
		0x1ac,
		0x1a5,
		0x1a4,
		0x1b4,
		0x1ad,
		0x1b1,
		0x1b7,
		0x1b6,
		0x1ae,
		0x1b2,
		0x1b8,
		0x1b0,
		0x1af,
		0x1c5,
		0x1bd,
		0x1c2,
		0x1c7,
		0x1c6,
		0x1be,
		0x1c4,
		0x1c9,
		0x1c0,
		0x1bf,
		0x1d7,
		0x1cc,
		0x1d1,
		0x1d9,
		0x1d8,
		0x1cd,
		0x1d4,
		0x1da,
		0x1d0,
		0x1ce,
		0x3ed,
		0x275,
		0x500,
		0x4ef,
		0x3e2,
		0x350,
		0x1ea,
		0x1dd,
		0x1e3,
		0x201,
		0x1ef,
		0x1df,
		0x1e6,
		0x203,
		0x1e1,
		0x1e0,
		0x23f,
		0x22f,
		0x234,
		0x276,
		0x245,
		0x231,
		0x237,
		0x278,
		0x233,
		0x232,
		0x28b,
		0x27c,
		0x286,
		0x2a6,
		0x298,
		0x280,
		0x288,
		0x2aa,
		0x283,
		0x281,
		0x2c4,
		0x2b2,
		0x2be,
		0x2d9,
		0x2d1,
		0x2ba,
		0x2c0,
		0x2dc,
		0x2bd,
		0x2bb,
		0x2f3,
		0x2e1,
		0x2e8,
		0x309,
		0x2f8,
		0x2e2,
		0x2ec,
		0x30b,
		0x2e5,
		0x2e3,
		0x31a,
		0x30f,
		0x313,
		0x333,
		0x31e,
		0x310,
		0x315,
		0x334,
		0x312,
		0x311,
		0x348,
		0x337,
		0x340,
		0x354,
		0x34c,
		0x33b,
		0x343,
		0x355,
		0x33d,
		0x33c,
		0x367,
		0x358,
		0x363,
		0x36b,
		0x368,
		0x35f,
		0x364,
		0x36c,
		0x361,
		0x360,
		0x380,
		0x371,
		0x376,
		0x391,
		0x383,
		0x372,
		0x37a,
		0x394,
		0x374,
		0x373,
		0x39d,
		0x395,
		0x39a,
		0x3a0,
		0x39e,
		0x396,
		0x39c,
		0x3a2,
		0x398,
		0x397,
		0x3ae,
		0x3a3,
		0x3aa,
		0x3b4,
		0x3b3,
		0x3a6,
		0x3ac,
		0x3b5,
		0x3a8,
		0x3a7,
		0x3d7,
		0x3ba,
		0x3ca,
		0x3f3,
		0x3dc,
		0x3c4,
		0x3ce,
		0x3f8,
		0x3c7,
		0x3c5,
		0x408,
		0x3fb,
		0x403,
		0x412,
		0x40f,
		0x400,
		0x406,
		0x415,
		0x402,
		0x401,
		0x430,
		0x41a,
		0x424,
		0x455,
		0x43e,
		0x41e,
		0x428,
		0x459,
		0x422,
		0x41f,
		0x474,
		0x461,
		0x469,
		0x488,
		0x47b,
		0x463,
		0x46e,
		0x48b,
		0x466,
		0x464,
		0x49c,
		0x48c,
		0x494,
		0x4b5,
		0x4aa,
		0x491,
		0x496,
		0x4b6,
		0x493,
		0x492,
		0x4be,
		0x4b8,
		0x4bc,
		0x4c0,
		0x4bf,
		0x4b9,
		0x4bd,
		0x4c2,
		0x4bb,
		0x4ba,
		0x4e2,
		0x4c7,
		0x4d7,
		0x4f3,
		0x4eb,
		0x4d1,
		0x4da,
		0x4f8,
		0x4d4,
		0x4d2,
		0x51b,
		0x4fb,
		0x50d,
		0x53a,
		0x525,
		0x4fe,
		0x512,
		0x541,
		0x503,
		0x4ff,
		0x55a,
		0x54c,
		0x554,
		0x570,
		0x568,
		0x54f,
		0x557,
		0x571,
		0x552,
		0x550,
		0x587,
		0x576,
		0x57f,
		0x599,
		0x58e,
		0x57b,
		0x584,
		0x59d,
		0x57d,
		0x57c,
		0x5ac,
		0x5a0,
		0x5a5,
		0x5b7,
		0x5ae,
		0x5a2,
		0x5a8,
		0x5b8,
		0x5a4,
		0x5a3,
		0x5c2,
		0x5b9,
		0x5be,
		0x5c5,
		0x5c3,
		0x5ba,
		0x5bf,
		0x5c6,
		0x5bc,
		0x5bb,
		0x5d0,
		0x5c7,
		0x5cc,
		0x5d7,
		0x5d5,
		0x5c8,
		0x5cd,
		0x5d8,
		0x5ca,
		0x5c9,
		0x5e5,
		0x5db,
		0x5e1,
		0x5e8,
		0x5e7,
		0x5dd,
		0x5e3,
		0x5eb,
		0x5df,
		0x5de,
		0x5f8,
		0x5ed,
		0x5f2,
		0x5fb,
		0x5fa,
		0x5ee,
		0x5f5,
		0x5fc,
		0x5f1,
		0x5ef,
		0x3cb,
		0x5ab,
		0x4d8,
		0x420,
		0x37c,
		0x28a,
		0x4ab,
		0x2ae,
		0x5e4,
		0x272,
		0x514,
		0x49,
		0x2ca,
		0x58f,
		0x2a2,
		0x483,
		0x3be,
		0x440,
		0x51f,
		0x4df,
		0x3fa,
		0x2c1,
		0x4a9,
		0x545,
		0x546,
		0x1e4,
		0x409,
		0x48f,
		0x40b,
		0x289,
		0x544,
		0x484,
		0x4ca,
		0x324,
		0x322,
		0x35a,
		0x32a,
		0x38e,
		0xd,
		0x2,
		0x8,
		0x14,
		0x16,
		0x13,
		0x0,
		0x2e,
		0x60,
		0x53,
		0x59,
		0x68,
		0xa6,
		0x9a,
		0x9f,
		0xaf,
		0x51,
		0x101,
		0x116,
		0x109,
		0x10f,
		0x11d,
		0x11f,
		0x566,
		0x11c,
		0x188,
		0x17a,
		0x181,
		0x192,
		0x1bc,
		0x164,
		0x54b,
		0x1e9,
		0x1dc,
		0x1e2,
		0x200,
		0x202,
		0x1fd,
		0x1e7,
		0x284,
		0x2f2,
		0x2e0,
		0x2e7,
		0x30a,
		0x37f,
		0x370,
		0x375,
		0x393,
		0x308,
		0x454,
		0x473,
		0x460,
		0x468,
		0x487,
		0x48a,
		0x2cb,
		0x485,
		0x586,
		0x575,
		0x57e,
		0x59c,
		0x5da,
		0x564,
		0x5ea,
		0x10,
		0x1ee,
		0x4,
		0x1de,
		0x12,
		0x1f8,
		0x27,
		0x27b,
		0x2f,
		0x285,
		0x31,
		0x287,
		0x2c,
		0x282,
		0x40,
		0x2bc,
		0x4b,
		0x2d8,
		0x62,
		0x2f7,
		0x5c,
		0x2eb,
		0x64,
		0x2ff,
		0x57,
		0x2e4,
		0x7d,
		0x33f,
		0x78,
		0x33a,
		0x80,
		0x342,
		0x7c,
		0x33e,
		0x8e,
		0x362,
		0x93,
		0x36a,
		0xac,
		0x390,
		0xa8,
		0x382,
		0xaa,
		0x38c,
		0xa3,
		0x387,
		0x388,
		0x97,
		0x381,
		0xb5,
		0x399,
		0xc7,
		0x3a9,
		0x3af,
		0xd1,
		0x3b9,
		0xd9,
		0x3c8,
		0xd7,
		0x3c6,
		0xe1,
		0x3dd,
		0xe2,
		0x3f0,
		0xf4,
		0x419,
		0xfa,
		0x423,
		0xf8,
		0x421,
		0x41c,
		0x50,
		0x2fd,
		0x118,
		0x47a,
		0x112,
		0x46c,
		0x105,
		0x470,
		0x13d,
		0x4c6,
		0x144,
		0x4d5,
		0x142,
		0x4d3,
		0x151,
		0x4fa,
		0x158,
		0x50c,
		0x157,
		0x506,
		0x155,
		0x502,
		0x16e,
		0x553,
		0x16c,
		0x551,
		0x176,
		0x56f,
		0x190,
		0x598,
		0x18a,
		0x58d,
		0x17d,
		0x57a,
		0x18f,
		0x597,
		0x184,
		0x581,
		0x18c,
		0x590,
		0x1a6,
		0x5bd,
		0x1c1,
		0x5e0,
		0x1c8,
		0x1cb,
		0x5ec,
		0x1d3,
		0x5f4,
		0x1cf,
		0x5f0,
		0x31f,
		0x10d,
		0x465,
		0x336,
		0x507,
		0x50a,
		0x508,
		0x50b,
		0x509,
		0x1fc,
		0x290,
		0x27f,
		0x271,
		0x2d3,
		0x4e7,
		0x471,
		0x565,
		0x2b9,
		0x1,
		0x52,
		0x4e,
		0x99,
		0x108,
		0x179,
		0x106,
		0x378,
		0xc,
		0xf,
		0x20,
		0x21,
		0x77,
		0x83,
		0x205,
		0x45,
		0x46,
		0x204,
		0x5f,
		0x65,
		0x1d5,
		0x1d6,
		0x4f,
		0x66,
		0x165,
		0x174,
		0x20c,
		0xa5,
		0xab,
		0xc3,
		0xcb,
		0xd3,
		0xdd,
		0x206,
		0xed,
		0xf1,
		0xfe,
		0x103,
		0x1b3,
		0x1b5,
		0x20e,
		0x115,
		0x11b,
		0x12a,
		0x12d,
		0x209,
		0x148,
		0x14a,
		0x15c,
		0x15e,
		0x20b,
		0x169,
		0x172,
		0x187,
		0x18d,
		0x18e,
		0x20d,
		0x121,
		0x12c,
		0x208,
		0x34,
		0xc0,
		0x122,
		0x130,
		0x20a,
		0x107,
		0x11a,
		0x207,
		0xa2,
		0x185,
		0x1db,
		0x2df,
		0x2ee,
		0x36f,
		0x582,
		0x1e8,
		0x1ed,
		0x20f,
		0x210,
		0x23c,
		0x23e,
		0x217,
		0x338,
		0x347,
		0x212,
		0x2c2,
		0x2c3,
		0x213,
		0x214,
		0x215,
		0x2f1,
		0x300,
		0x301,
		0x22e,
		0x5f6,
		0x5f7,
		0x216,
		0x2ef,
		0x307,
		0x22a,
		0x55c,
		0x55d,
		0x560,
		0x219,
		0x37e,
		0x38d,
		0x21a,
		0x3a4,
		0x3ad,
		0x21c,
		0x3bc,
		0x3d6,
		0x21d,
		0x407,
		0x413,
		0x21e,
		0x42f,
		0x456,
		0x22d,
		0x5cf,
		0x5d3,
		0x472,
		0x47d,
		0x222,
		0x49b,
		0x4a3,
		0x225,
		0x4e1,
		0x4e5,
		0x228,
		0x518,
		0x521,
		0x522,
		0x227,
		0x51a,
		0x520,
		0x229,
		0x54e,
		0x559,
		0x22c,
		0x585,
		0x592,
		0x594,
		0x220,
		0x49d,
		0x49e,
		0x49f,
		0x211,
		0x28e,
		0x3b1,
		0x224,
		0x4b3,
		0x4b4,
		0x476,
		0x47c,
		0x379,
		0x583,
		0x45f,
		0x574,
		0x21f,
		0x475,
		0x22b,
		0x55e,
		0x55f,
		0x593,
		0x221,
		0x4a0,
		0x223,
		0x4a4,
		0x218,
		0x339,
		0x21b,
		0x3a5,
		0x226,
		0x4e6,
		0x98,
		0x39,
		0x75,
		0xbd,
		0x3a,
		0xae,
		0x1ba,
		0xbb,
		0xd0,
		0xf3,
		0x166,
		0xc1,
		0x17c,
		0x3b,
		0xa,
		0x1e,
		0x199,
		0x7f,
		0x43,
		0x96,
		0x1ca,
		0x1d2,
		0xa1,
		0xb7,
		0xc9,
		0xdb,
		0xeb,
		0xfc,
		0x111,
		0x128,
		0x146,
		0x15a,
		0x170,
		0x183,
		0x6f,
		0xbf,
		0x167,
		0x26,
		0x14f,
		0x14e,
		0x89,
		0x1c3,
		0x150,
		0x5b,
		0x1bb,
		0x1b9,
		0x1e5,
		0x236,
		0x5a6,
		0x341,
		0x2bf,
		0x37b,
		0x5f9,
		0x5f3,
		0x377,
		0x39b,
		0x3ab,
		0x3cc,
		0x404,
		0x426,
		0x46a,
		0x495,
		0x4d9,
		0x510,
		0x555,
		0x580,
		0x314,
		0x3b0,
		0x56d,
		0x28c,
		0x51e,
		0x51d,
		0x35c,
		0x5e2,
		0x527,
		0x2ea,
		0x5e9,
		0x5dc,
		0x38b,
		0x2cd,
		0x34a,
		0x3a1,
		0x2d7,
		0x392,
		0x5e6,
		0x39f,
		0x3db,
		0x435,
		0x56e,
		0x3b2,
		0x579,
		0x2dd,
		0x5e,
		0x2ed,
		0x114,
		0x46f,
		0x2fe,
		0x2fa,
		0x2fb,
		0x2fc,
		0x45a,
		0x4b7,
		0x561,
		0x359,
		0x5fe,
		0x5fd,
		0x3e9,
		0x4ea,
		0x2b7,
		0x427,
		0x405,
		0x369,
		0x19c,
		0x3ee,
		0x4f1,
		0x4f0,
		0x3ef,
		0x4fd,
		0x3cf,
		0x4dc,
		0x4db,
		0x238,
		0x3d0,
		0x2b3,
		0x3d,
		0x277,
		0x438,
		0x366,
		0x40e,
		0x499,
		0x4ae,
		0x5af,
		0x12f,
		0x56a,
		0x270,
		0x3ea,
		0x4ed,
		0x479,
		0x27e,
		0x36d,
		0x331,
		0x30c,
		0x556,
		0x4a,
		0x385,
		0x35b,
		0x4a5,
		0x384,
		0x3bb,
		0x2f5,
		0x458,
		0x2a3,
		0x5c1,
		0x4dd,
		0x4f9,
		0x56b,
		0x477,
		0x1f7,
		0x23b,
		0x4a1,
		0x482,
		0x1eb,
		0x1ec,
		0x23d,
		0x349,
		0x2b4,
		0x323,
		0x328,
		0x325,
		0x329,
		0x32b,
		0x32d,
		0x326,
		0x32e,
		0x327,
		0x32c,
		0x32f,
		0x330,
		0x3bf,
		0x577,
		0x4cb,
		0x2b5,
		0x35d,
		0x5d1,
		0x5d2,
		0x5a1,
		0x45d,
		0x42a,
		0x2d4,
		0x2ce,
		0x437,
		0x446,
		0x4d0,
		0xd4,
		0x13f,
		0x3c3,
		0x4cf,
		0x3fe,
		0x3c1,
		0x4cd,
		0x3c2,
		0x4ce,
		0x35e,
		0x433,
		0x3eb,
		0x4ee,
		0x2a4,
		0x2a9,
		0x2ad,
		0x478,
		0x481,
		0x3d9,
		0x3d8,
		0x589,
		0x588,
		0x4e4,
		0x4e3,
		0x2c6,
		0x2c5,
		0x4e8,
		0x3e7,
		0x3c0,
		0x578,
		0x4cc,
		0x2b6,
		0x3e8,
		0x4e9,
		0x436,
		0x432,
		0x445,
		0x3b7,
		0x5d4,
		0x573,
		0x4c5,
		0x5d6,
		0x2b1,
		0x357,
		0x37d,
		0x59e,
		0x3b6,
		0x4c4,
		0x320,
		0x29d,
		0x490,
		0x30e,
		0x42c,
		0x2f9,
		0x418,
		0x38f,
		0x441,
		0x302,
		0x434,
		0x23a,
		0x4b0,
		0x1f0,
		0x2a1,
		0x4fc,
		0x540,
		0x40c,
		0x410,
		0x4a8,
		0x516,
		0x535,
		0x3e1,
		0x29e,
		0x4c8,
		0x4b1,
		0x5b0,
		0x386,
		0x1f4,
		0x1f3,
		0x1f5,
		0x1f6,
		0x40a,
		0x43f,
		0x48e,
		0x52a,
		0x442,
		0x44d,
		0x1f2,
		0x480,
		0x27d,
		0x2ab,
		0x389,
		0x2a0,
		0x55b,
		0x239,
		0x523,
		0x563,
		0x273,
		0x5c4,
		0x44b,
		0x524,
		0x44c,
		0x29f,
		0x425,
		0x1f9,
		0x1ff,
		0x562,
		0x41b,
		0x1fa,
		0x235,
		0x279,
		0x27a,
		0x306,
		0x2de,
		0x2f0,
		0x305,
		0x29a,
		0x2e9,
		0x2e6,
		0x296,
		0x5c0,
		0x56c,
		0x429,
		0x304,
		0x42b,
		0x3d1,
		0x3d3,
		0x344,
		0x346,
		0x3b8,
		0x335,
		0x3de,
		0x3df,
		0x3f9,
		0x34d,
		0x34e,
		0x356,
		0xe3,
		0x86,
		0x572,
		0x43b,
		0x431,
		0x439,
		0x43a,
		0x42d,
		0x42e,
		0x3ec,
		0x352,
		0x3d5,
		0x34b,
		0x4ac,
		0x501,
		0x2ac,
		0x4ad,
		0x504,
		0x505,
		0x4b2,
		0x50f,
		0x443,
		0x449,
		0x53b,
		0x543,
		0x44e,
		0x451,
		0x53c,
		0x53d,
		0x547,
		0x548,
		0x44f,
		0x450,
		0x452,
		0x453,
		0x53e,
		0x53f,
		0x5b2,
		0x5b3,
		0x549,
		0x54a,
		0x5b4,
		0x5b5,
		0x591,
		0x52d,
		0x52f,
		0x52e,
		0x530,
		0x52b,
		0x52c,
		0x47f,
		0x47e,
		0x489,
		0x486,
		0x46d,
		0x467,
		0x462,
		0x46b,
		0x4a7,
		0x40d,
		0x567,
		0x513,
		0x5a7,
		0x2b8,
		0x569,
		0x246,
		0x49a,
		0x411,
		0x59f,
		0x19a,
		0x1a1,
		0x45c,
		0x45b,
		0x417,
		0x416,
		0x5ad,
		0x5b1,
		0x3f6,
		0x4f6,
		0x414,
		0x38a,
		0x5a9,
		0x230,
		0x2c7,
		0x511,
		0x537,
		0x2cc,
		0x247,
		0x3f4,
		0x4f4,
		0x3f2,
		0x4f2,
		0x274,
		0x2af,
		0x2b0,
		0x161,
		0x163,
		0x29,
		0x38,
		0x321,
		0x3cd,
		0x351,
		0xdf,
		0x82,
		0x3d2,
		0x345,
		0x2f6,
		0x2f4,
		0x2a7,
		0x2a8,
		0x444,
		0x44a,
		0x3e0,
		0x34f,
		0x4af,
		0x50e,
		0x43c,
		0x447,
		0x43d,
		0x448,
		0x5aa,
		0x19,
		0x3c9,
		0x4d6,
		0x3d4,
		0x4e0,
		0x2d6,
		0x2d0,
		0x596,
		0x58c,
		0x558,
		0x54d,
		0x58b,
		0x595,
		0x2cf,
		0x2d5,
		0x332,
		0x519,
		0x526,
		0x536,
		0x3bd,
		0x4c9,
		0x240,
		0x45e,
		0x260,
		0x269,
		0x25f,
		0x25e,
		0x268,
		0x267,
		0x26f,
		0x26e,
		0x263,
		0x264,
		0x26d,
		0x24c,
		0x255,
		0x25d,
		0x24b,
		0x249,
		0x25c,
		0x24a,
		0x248,
		0x266,
		0x254,
		0x252,
		0x265,
		0x253,
		0x251,
		0x26c,
		0x25b,
		0x258,
		0x26b,
		0x25a,
		0x257,
		0x24f,
		0x261,
		0x24d,
		0x250,
		0x262,
		0x24e,
		0x26a,
		0x259,
		0x256,
		0x58a,
		0x3da,
		0x244,
		0x242,
		0x241,
		0x243,
		0x533,
		0x531,
		0x532,
		0x534,
		0x4de,
		0x3ff,
		0x5d9,
		0x59b,
		0x59a,
		0x4f7,
		0x4f5,
		0x5ce,
		0x2db,
		0x2da,
		0x3f7,
		0x3f5,
		0x2c8,
		0x3e3,
		0x28f,
		0x5cb,
		0x291,
		0x293,
		0x294,
		0x292,
		0x295,
		0x539,
		0x538,
		0x4a2,
		0x316,
		0x3fc,
		0x529,
		0x297,
		0x365,
		0x2c9,
		0x542,
		0x31c,
		0x41d,
		0x51c,
		0x28d,
		0x2a5,
		0x3fd,
		0x3e5,
		0x3e4,
		0x517,
		0x318,
		0x31b,
		0x31d,
		0x317,
		0x319,
	};
	/// \endcond
}
